Installation
============

One could easily install Piquasso with the following command:

.. code-block:: bash

   pip install piquasso

For a basic example, check out :doc:`tutorials/getting-started`.

One can also use Piquasso along with TensorFlow, see, e.g.,
:doc:`tutorials/cvqnn-with-tensorflow`. To install Piquasso with TensorFlow, just enter

.. code-block:: bash

   pip install piquasso[tensorflow]


Similarly, Piquasso admits a JAX support, as described in :doc:`tutorials/jax-example`
To install Piquasso with JAX is done by

.. code-block:: bash

   pip install piquasso[jax]
